@@ -2,10 +2,10 @@
  * Photos - access, organize and share your photos on GNOME
  * Copyright © 2012 – 2017 Red Hat, Inc.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Based on code from:
@@ -40,15 +38,18 @@ struct _PhotosFilterableInterface
   gchar *(*get_filter) (PhotosFilterable *self);
   const gchar *(*get_id) (PhotosFilterable *self);
   gchar *(*get_where) (PhotosFilterable *self);
+  gboolean (*is_search_criterion) (PhotosFilterable *self);
 };
 
 gboolean            photos_filterable_get_builtin        (PhotosFilterable *self);
 
-gchar              *photos_filterable_get_filter         (PhotosFilterable *iface);
+gchar              *photos_filterable_get_filter         (PhotosFilterable *self);
 
 const gchar        *photos_filterable_get_id             (PhotosFilterable *self);
 
-gchar              *photos_filterable_get_where          (PhotosFilterable *iface);
+gchar              *photos_filterable_get_where          (PhotosFilterable *self);
+
+gboolean            photos_filterable_is_search_criterion  (PhotosFilterable *self);
 
 G_END_DECLS
 
