@@ -3,10 +3,10 @@
  * Copyright © 2014 – 2017 Red Hat, Inc.
  * Copyright © 2014 Saurav Agarwalla
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Based on code from:
@@ -189,13 +187,13 @@ photos_google_item_create_thumbnail (PhotosBaseItem *item, GCancellable *cancell
   thumbnail_uri = gdata_media_thumbnail_get_uri (thumbnail);
   remote_file = g_file_new_for_uri (thumbnail_uri);
 
-  uri = photos_base_item_get_uri (item);
-  local_path = photos_utils_get_thumbnail_path_for_uri (uri);
+  local_path = photos_base_item_create_thumbnail_path (item);
   local_file = g_file_new_for_path (local_path);
-
   local_dir = g_path_get_dirname (local_path);
   g_mkdir_with_parents (local_dir, 0700);
 
+  uri = photos_base_item_get_uri (item);
+
   height = photos_base_item_get_height (item);
   width = photos_base_item_get_width (item);
 
