@@ -23,20 +23,20 @@
 
 #include "config.h"
 
+#include <dazzle.h>
 #include <glib.h>
 
-#include "egg-counter.h"
 #include "photos-application.h"
 #include "photos-debug.h"
 #include "photos-remote-display-manager.h"
 
 
 static void
-photos_main_counter_arena_foreach (EggCounter *counter, gpointer user_data)
+photos_main_counter_arena_foreach (DzlCounter *counter, gpointer user_data)
 {
   gint64 count;
 
-  count = egg_counter_get (counter);
+  count = dzl_counter_get (counter);
   photos_debug (PHOTOS_DEBUG_MEMORY, "%s.%s = %" G_GINT64_FORMAT, counter->category, counter->name, count);
 }
 
@@ -44,7 +44,7 @@ photos_main_counter_arena_foreach (EggCounter *counter, gpointer user_data)
 gint
 main (gint argc, gchar *argv[])
 {
-  EggCounterArena *counter_arena;
+  DzlCounterArena *counter_arena;
   gint exit_status;
 
   {
@@ -61,8 +61,8 @@ main (gint argc, gchar *argv[])
     exit_status = g_application_run (app, argc, argv);
   }
 
-  counter_arena = egg_counter_arena_get_default ();
-  egg_counter_arena_foreach (counter_arena, photos_main_counter_arena_foreach, NULL);
+  counter_arena = dzl_counter_arena_get_default ();
+  dzl_counter_arena_foreach (counter_arena, photos_main_counter_arena_foreach, NULL);
 
   return exit_status;
 }
