@@ -23,12 +23,12 @@
 
 #include "config.h"
 
+#include <dazzle.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 
 #include <gio/gio.h>
 
-#include "egg-counter.h"
 #include "photos-base-manager.h"
 #include "photos-debug.h"
 #include "photos-enums.h"
@@ -81,7 +81,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PhotosTrackerController, photos_tracker_controller, G_TYPE_OBJECT);
-EGG_DEFINE_COUNTER (instances,
+DZL_DEFINE_COUNTER (instances,
                     "PhotosTrackerController",
                     "Instances",
                     "Number of PhotosTrackerController instances")
@@ -199,9 +199,8 @@ photos_tracker_controller_query_finished (PhotosTrackerController *self, GError
 static void
 photos_tracker_controller_cursor_next (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosTrackerController *self = PHOTOS_TRACKER_CONTROLLER (user_data);
+  g_autoptr (PhotosTrackerController) self = PHOTOS_TRACKER_CONTROLLER (user_data);
   PhotosTrackerControllerPrivate *priv;
-  GError *error;
   TrackerSparqlCursor *cursor = TRACKER_SPARQL_CURSOR (source_object);
   gboolean success;
   gint64 now;
@@ -211,17 +210,19 @@ photos_tracker_controller_cursor_next (GObject *source_object, GAsyncResult *res
   if (priv->item_mngr == NULL)
     goto out;
 
-  error = NULL;
-  /* Note that tracker_sparql_cursor_next_finish can return FALSE even
-   * without an error.
-   */
-  success = tracker_sparql_cursor_next_finish (cursor, res, &error);
-  if (error != NULL)
-    {
-      photos_tracker_controller_query_finished (self, error);
-      g_error_free (error);
-      goto out;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    /* Note that tracker_sparql_cursor_next_finish can return FALSE even
+     * without an error.
+     */
+    success = tracker_sparql_cursor_next_finish (cursor, res, &error);
+    if (error != NULL)
+      {
+        photos_tracker_controller_query_finished (self, error);
+        goto out;
+      }
+  }
 
   if (!success)
     {
@@ -244,7 +245,7 @@ photos_tracker_controller_cursor_next (GObject *source_object, GAsyncResult *res
                                     g_object_ref (self));
 
  out:
-  g_object_unref (self);
+  return;
 }
 
 
@@ -254,19 +255,20 @@ photos_tracker_controller_query_executed (GObject *source_object, GAsyncResult *
   PhotosTrackerController *self = PHOTOS_TRACKER_CONTROLLER (user_data);
   PhotosTrackerControllerPrivate *priv;
   TrackerSparqlConnection *connection = TRACKER_SPARQL_CONNECTION (source_object);
-  GError *error;
-  TrackerSparqlCursor *cursor;
+  TrackerSparqlCursor *cursor; /* Use g_autoptr */
 
   priv = photos_tracker_controller_get_instance_private (self);
 
-  error = NULL;
-  cursor = tracker_sparql_connection_query_finish (connection, res, &error);
-  if (error != NULL)
-    {
-      photos_tracker_controller_query_finished (self, error);
-      g_error_free (error);
-      return;
-    }
+  {
+    g_autoptr (GError) error = NULL;
+
+    cursor = tracker_sparql_connection_query_finish (connection, res, &error);
+    if (error != NULL)
+      {
+        photos_tracker_controller_query_finished (self, error);
+        return;
+      }
+  }
 
   tracker_sparql_cursor_next_async (cursor,
                                     priv->cancellable,
@@ -281,7 +283,7 @@ photos_tracker_controller_perform_current_query (PhotosTrackerController *self)
 {
   PhotosTrackerControllerPrivate *priv;
   const gchar *type_name;
-  gchar *tag = NULL;
+  g_autofree gchar *tag = NULL;
 
   priv = photos_tracker_controller_get_instance_private (self);
 
@@ -310,7 +312,7 @@ photos_tracker_controller_perform_current_query (PhotosTrackerController *self)
                                g_object_unref);
 
  out:
-  g_free (tag);
+  return;
 }
 
 
@@ -518,7 +520,7 @@ photos_tracker_controller_finalize (GObject *object)
 
   G_OBJECT_CLASS (photos_tracker_controller_parent_class)->finalize (object);
 
-  EGG_COUNTER_DEC (instances);
+  DZL_COUNTER_DEC (instances);
 }
 
 
@@ -554,7 +556,7 @@ photos_tracker_controller_init (PhotosTrackerController *self)
   GApplication *app;
   PhotosSearchContextState *state;
 
-  EGG_COUNTER_INC (instances);
+  DZL_COUNTER_INC (instances);
 
   priv = photos_tracker_controller_get_instance_private (self);
 
