@@ -146,7 +146,7 @@ GList           *photos_utils_get_urns_from_items         (GList *items);
 
 const gchar     *photos_utils_get_version                 (void);
 
-gboolean         photos_utils_launch_online_accounts      (const gchar *account_id, GError **error);
+void             photos_utils_launch_online_accounts      (const gchar *account_id);
 
 void             photos_utils_list_box_header_func        (GtkListBoxRow *row,
                                                            GtkListBoxRow *before,
